@@ -40,6 +40,7 @@ Security8021x::Security8021x(const NetworkManager::Setting::Ptr &setting, bool w
     m_ui->leapPassword->setPasswordOptionsEnabled(true);
     m_ui->md5Password->setPasswordOptionsEnabled(true);
     m_ui->peapPassword->setPasswordOptionsEnabled(true);
+    m_ui->pwdPassword->setPasswordOptionsEnabled(true);
     m_ui->tlsPrivateKeyPassword->setPasswordOptionsEnabled(true);
     m_ui->ttlsPassword->setPasswordOptionsEnabled(true);
 
@@ -49,18 +50,20 @@ Security8021x::Security8021x(const NetworkManager::Setting::Ptr &setting, bool w
 
         m_ui->auth->setItemData(0, NetworkManager::Security8021xSetting::EapMethodTls);
         m_ui->auth->setItemData(1, NetworkManager::Security8021xSetting::EapMethodLeap);
-        m_ui->auth->setItemData(2, NetworkManager::Security8021xSetting::EapMethodFast);
-        m_ui->auth->setItemData(3, NetworkManager::Security8021xSetting::EapMethodTtls);
-        m_ui->auth->setItemData(4, NetworkManager::Security8021xSetting::EapMethodPeap);
+        m_ui->auth->setItemData(2, NetworkManager::Security8021xSetting::EapMethodPwd);
+        m_ui->auth->setItemData(3, NetworkManager::Security8021xSetting::EapMethodFast);
+        m_ui->auth->setItemData(4, NetworkManager::Security8021xSetting::EapMethodTtls);
+        m_ui->auth->setItemData(5, NetworkManager::Security8021xSetting::EapMethodPeap);
     } else {
         m_ui->auth->removeItem(2); // LEAP
         m_ui->stackedWidget->removeWidget(m_ui->leapPage);
 
         m_ui->auth->setItemData(0, NetworkManager::Security8021xSetting::EapMethodMd5);
         m_ui->auth->setItemData(1, NetworkManager::Security8021xSetting::EapMethodTls);
-        m_ui->auth->setItemData(2, NetworkManager::Security8021xSetting::EapMethodFast);
-        m_ui->auth->setItemData(3, NetworkManager::Security8021xSetting::EapMethodTtls);
-        m_ui->auth->setItemData(4, NetworkManager::Security8021xSetting::EapMethodPeap);
+        m_ui->auth->setItemData(2, NetworkManager::Security8021xSetting::EapMethodPwd);
+        m_ui->auth->setItemData(3, NetworkManager::Security8021xSetting::EapMethodFast);
+        m_ui->auth->setItemData(4, NetworkManager::Security8021xSetting::EapMethodTtls);
+        m_ui->auth->setItemData(5, NetworkManager::Security8021xSetting::EapMethodPeap);
     }
 
     // Set PEAP authentication as default
@@ -88,6 +91,8 @@ Security8021x::Security8021x(const NetworkManager::Setting::Ptr &setting, bool w
     connect(m_ui->leapPassword, &PasswordField::passwordOptionChanged, this, &Security8021x::slotWidgetChanged);
     connect(m_ui->fastAllowPacProvisioning, &QCheckBox::stateChanged, this, &Security8021x::slotWidgetChanged);
     connect(m_ui->pacFile, &KUrlRequester::textChanged, this, &Security8021x::slotWidgetChanged);
+    connect(m_ui->pwdUsername, &KLineEdit::textChanged, this, &Security8021x::slotWidgetChanged);
+    connect(m_ui->pwdPassword, &PasswordField::textChanged, this, &Security8021x::slotWidgetChanged);
     connect(m_ui->fastUsername, &KLineEdit::textChanged, this, &Security8021x::slotWidgetChanged);
     connect(m_ui->fastPassword, &PasswordField::textChanged, this, &Security8021x::slotWidgetChanged);
     connect(m_ui->fastPassword, &PasswordField::passwordOptionChanged, this, &Security8021x::slotWidgetChanged);
@@ -146,6 +151,7 @@ void Security8021x::loadConfig(const NetworkManager::Setting::Ptr &setting)
         QStringList servers;
         m_ui->auth->setCurrentIndex(m_ui->auth->findData(NetworkManager::Security8021xSetting::EapMethodTls));
         m_ui->tlsIdentity->setText(securitySetting->identity());
+        m_ui->tlsDomain->setText(securitySetting->domainSuffixMatch());
         m_ui->tlsUserCert->setUrl(QUrl::fromLocalFile(securitySetting->clientCertificate()));
         m_ui->tlsCACert->setUrl(QUrl::fromLocalFile(securitySetting->caCertificate()));
         m_ui->leTlsSubjectMatch->setText(securitySetting->subjectMatch());
@@ -174,6 +180,18 @@ void Security8021x::loadConfig(const NetworkManager::Setting::Ptr &setting)
         } else {
             m_ui->leapPassword->setPasswordOption(PasswordField::AlwaysAsk);
         }
+
+    } else if (eapMethods.contains(NetworkManager::Security8021xSetting::EapMethodPwd)) {
+        m_ui->auth->setCurrentIndex(m_ui->auth->findData(NetworkManager::Security8021xSetting::EapMethodPwd));
+        m_ui->pwdUsername->setText(securitySetting->identity());
+
+        if (securitySetting->passwordFlags().testFlag(NetworkManager::Setting::None)) {
+            m_ui->pwdPassword->setPasswordOption(PasswordField::StoreForAllUsers);
+        } else if (securitySetting->passwordFlags().testFlag(NetworkManager::Setting::AgentOwned)) {
+            m_ui->pwdPassword->setPasswordOption(PasswordField::StoreForUser);
+        } else {
+            m_ui->pwdPassword->setPasswordOption(PasswordField::AlwaysAsk);
+        }
     } else if (eapMethods.contains(NetworkManager::Security8021xSetting::EapMethodFast)) {
         m_ui->auth->setCurrentIndex(m_ui->auth->findData(NetworkManager::Security8021xSetting::EapMethodFast));
         m_ui->fastAnonIdentity->setText(securitySetting->anonymousIdentity());
@@ -196,6 +214,7 @@ void Security8021x::loadConfig(const NetworkManager::Setting::Ptr &setting)
     } else if (eapMethods.contains(NetworkManager::Security8021xSetting::EapMethodTtls)) {
         m_ui->auth->setCurrentIndex(m_ui->auth->findData(NetworkManager::Security8021xSetting::EapMethodTtls));
         m_ui->ttlsAnonIdentity->setText(securitySetting->anonymousIdentity());
+        m_ui->ttlsDomain->setText(securitySetting->domainSuffixMatch());
         m_ui->ttlsCACert->setUrl(QUrl::fromLocalFile(securitySetting->caCertificate()));
         if (phase2AuthMethod == NetworkManager::Security8021xSetting::AuthMethodPap) {
             m_ui->ttlsInnerAuth->setCurrentIndex(0);
@@ -217,6 +236,7 @@ void Security8021x::loadConfig(const NetworkManager::Setting::Ptr &setting)
     } else if (eapMethods.contains(NetworkManager::Security8021xSetting::EapMethodPeap)) {
         m_ui->auth->setCurrentIndex(m_ui->auth->findData(NetworkManager::Security8021xSetting::EapMethodPeap));
         m_ui->peapAnonIdentity->setText(securitySetting->anonymousIdentity());
+        m_ui->peapDomain->setText(securitySetting->domainSuffixMatch());
         m_ui->peapCACert->setUrl(QUrl::fromLocalFile(securitySetting->caCertificate()));
         m_ui->peapVersion->setCurrentIndex(securitySetting->phase1PeapVersion() + 1);
         if (phase2AuthMethod == NetworkManager::Security8021xSetting::AuthMethodMschapv2) {
@@ -253,6 +273,8 @@ void Security8021x::loadSecrets(const NetworkManager::Setting::Ptr &setting)
             m_ui->leapPassword->setText(securitySetting->password());
         } else if (eapMethods.contains(NetworkManager::Security8021xSetting::EapMethodFast)) {
             m_ui->fastPassword->setText(securitySetting->password());
+        } else if (eapMethods.contains(NetworkManager::Security8021xSetting::EapMethodPwd)) {
+            m_ui->pwdPassword->setText(securitySetting->password());
         } else if (eapMethods.contains(NetworkManager::Security8021xSetting::EapMethodTtls)) {
             m_ui->ttlsPassword->setText(securitySetting->password());
         } else if (eapMethods.contains(NetworkManager::Security8021xSetting::EapMethodPeap)) {
@@ -298,6 +320,10 @@ QVariantMap Security8021x::setting() const
             setting.setIdentity(m_ui->tlsIdentity->text());
         }
 
+        if (!m_ui->tlsDomain->text().isEmpty()) {
+            setting.setDomainSuffixMatch(m_ui->tlsDomain->text());
+        }
+
         if (m_ui->tlsUserCert->url().isValid()) {
             setting.setClientCertificate(m_ui->tlsUserCert->url().toString().toUtf8().append('\0'));
         }
@@ -359,6 +385,22 @@ QVariantMap Security8021x::setting() const
         } else {
             setting.setPasswordFlags(NetworkManager::Setting::NotSaved);
         }
+    } else if (method == NetworkManager::Security8021xSetting::EapMethodPwd) {
+        if (!m_ui->pwdUsername->text().isEmpty()) {
+            setting.setIdentity(m_ui->pwdUsername->text());
+        }
+
+        if (m_ui->pwdPassword->passwordOption() == PasswordField::StoreForAllUsers) {
+            setting.setPasswordFlags(NetworkManager::Setting::None);
+        } else if (m_ui->pwdPassword->passwordOption() == PasswordField::StoreForUser) {
+            setting.setPasswordFlags(NetworkManager::Setting::AgentOwned);
+        } else {
+            setting.setPasswordFlags(NetworkManager::Setting::NotSaved);
+        }
+
+        if (!m_ui->pwdPassword->text().isEmpty()) {
+            setting.setPassword(m_ui->pwdPassword->text());
+        }
     } else if (method == NetworkManager::Security8021xSetting::EapMethodFast) {
         if (!m_ui->fastAnonIdentity->text().isEmpty()) {
             setting.setAnonymousIdentity(m_ui->fastAnonIdentity->text());
@@ -400,6 +442,10 @@ QVariantMap Security8021x::setting() const
             setting.setAnonymousIdentity(m_ui->ttlsAnonIdentity->text());
         }
 
+        if (!m_ui->ttlsDomain->text().isEmpty()) {
+            setting.setDomainSuffixMatch(m_ui->ttlsDomain->text());
+        }
+
         if (m_ui->ttlsCACert->url().isValid()) {
             setting.setCaCertificate(m_ui->ttlsCACert->url().toString().toUtf8().append('\0'));
         }
@@ -435,6 +481,10 @@ QVariantMap Security8021x::setting() const
             setting.setAnonymousIdentity(m_ui->peapAnonIdentity->text());
         }
 
+        if (!m_ui->peapDomain->text().isEmpty()) {
+            setting.setDomainSuffixMatch(m_ui->peapDomain->text());
+        }
+
         if (m_ui->peapCACert->url().isValid()) {
             setting.setCaCertificate(m_ui->peapCACert->url().toString().toUtf8().append('\0'));
         }
@@ -565,6 +615,8 @@ bool Security8021x::isValid() const
         // TODO Validate other certificates??
     } else if (method == NetworkManager::Security8021xSetting::EapMethodLeap) {
         return !m_ui->leapUsername->text().isEmpty() && (!m_ui->leapPassword->text().isEmpty() || m_ui->leapPassword->passwordOption() == PasswordField::AlwaysAsk);
+    } else if (method == NetworkManager::Security8021xSetting::EapMethodPwd) {
+        return !m_ui->pwdUsername->text().isEmpty() && (!m_ui->pwdPassword->text().isEmpty() || m_ui->pwdPassword->passwordOption() == PasswordField::AlwaysAsk);
     } else if (method == NetworkManager::Security8021xSetting::EapMethodFast) {
         if (!m_ui->fastAllowPacProvisioning->isChecked() && !m_ui->pacFile->url().isValid()) {
             return false;
