@@ -1,4 +1,4 @@
 #! /usr/bin/env bash
 $EXTRACTRC `find . -name "*.ui" -o -name "*.rc"` >> rc.cpp
-$XGETTEXT `find . -name "*.cpp"` -o $podir/plasmanm_pptpui.pot
+$XGETTEXT `find . -name "*.cpp"` -o $podir/plasmanetworkmanagement_pptpui.pot
 rm -f rc.cpp
